.. FreeDiscovery documentation master file, created by
   sphinx-quickstart on Sun Jul 10 13:58:31 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst


Contents
^^^^^^^^

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   engine/index
   python/index
   user_manual/index
   contributing
   whats_new



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

